# DatasetColumnSource

Reference to a dataset column

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | Name of the dataset column | 

## Example

```python
from _generated.models.dataset_column_source import DatasetColumnSource

# TODO update the JSON string below
json = "{}"
# create an instance of DatasetColumnSource from a JSON string
dataset_column_source_instance = DatasetColumnSource.from_json(json)
# print the JSON string representation of the object
print(DatasetColumnSource.to_json())

# convert the object into a dict
dataset_column_source_dict = dataset_column_source_instance.to_dict()
# create an instance of DatasetColumnSource from a dict
dataset_column_source_from_dict = DatasetColumnSource.from_dict(dataset_column_source_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


